@@ -1,3 +1,3 @@
 from DataStand.DataStand import DataStand
 from DataStand.DataStand import impute_missing
-from DataStand,DataStand import plot_missing
+from DataStand.DataStand import plot_missing
